import 'dart:convert';

import 'package:http/http.dart' as http;
import 'package:rayconnect_client/core/storage.dart' as storage;

class Http {
  String _appId;

  Http({String appId}) {
    this._appId = appId;
  }

  // create http header with auth token
  Future<Map<String, String>> _headers({bool auth = true}) async {
    Map header = new Map();
    if (auth == true) {
      String token = await storage.getItem('rayconnect-token');
      if (token != null) header['token'] = token;
    }
    header['content-type'] = 'application/json';
    if (this._appId != null && this._appId.length != 0)
      header['aid'] = this._appId;
    return Map<String, String>.from(header);
  }

  // http request with 'GET' method
  Future<dynamic> get({
    String url,
    bool auth = false,
  }) async {
    try {
      // Make http headers
      Map<String, String> header = await this._headers(auth: auth);
      http.Response response = await http.get(
        url,
        headers: header,
      );
      // return response as json
      return await jsonDecode(response.body);
    } catch (e) {
      return null;
    }
  }

  // http request with 'POST' method
  Future<dynamic> post({
    String url,
    bool auth = false,
    Map data,
  }) async {
    try {
      // Make http headers
      Map<String, String> header = await this._headers(auth: auth);
      http.Response response = await http.post(
        url,
        headers: header,
        body: jsonEncode(data), // pass http post body as string json
      );
      // return response as json
      return await jsonDecode(response.body);
    } catch (e) {
      return null;
    }
  }
}
