import 'package:rayconnect_client/core/http.dart';
import 'package:rayconnect_client/core/storage.dart' as storage;

class Auth {
  final String appId;
  Http _http = new Http();

  Auth({this.appId});

  // get guest access token
  Future<String> getTokenAsGuest() async {
    try {
      Map result = await this._http.get(
            url:
                'https://s1.iranserver1.rayconnect.ir/api/v2/guest?aid=${this.appId}',
            auth: false,
          );
      return result['status'] == true ? result['token'] : null;
    } catch (error) {
      return null;
    }
  }

  // get guest access token and save the token
  Future<void> asGuest() async {
    String token = await this.getTokenAsGuest();
    await storage.setItem('rayconnect-token', token);
    await storage.setItem('rayconnect-uid', 'guest');
  }

  // sms a code to user by phone
  Future<bool> sendCode(String phone) async {
    Map result = await this._http.post(
          url:
              'https://s1.iranserver1.rayconnect.ir/api/v2/otp?appID=${this.appId}',
          data: {'phone': phone},
          auth: false,
        );
    return result['status'];
  }

  // verify smsed code
  Future<Map> verifyCode(String phone, String token) async {
    Map result = await this._http.post(
          url:
              'https://s1.iranserver1.rayconnect.ir/api/v2/otp?appID=${this.appId}',
          data: {'phone': phone, 'tokenNumber': token},
          auth: false,
        );
    return result;
  }

  // set auth token
  Future<void> setToken(String token) async {
    await storage.setItem('rayconnect-token', token);
  }

  // get auth token
  Future<String> getToken() async {
    return await storage.getItem('rayconnect-token');
  }

  // is an auth token saved
  Future<bool> hasToken() async {
    return await storage.getItem('rayconnect-token') != null;
  }

  // get user id by it's token and it should be guest or uuid id or phone number (old version of rayconnect core can send phone number)
  Future<String> getUserId() async {
    String uid = await storage.getItem('rayconnect-uid');
    // if was an uid return that else fetch
    return uid == null ? await this.fetchUserId() : uid;
  }

  // fetch user id by it's token and it should be guest or uuid id or phone number (old version of rayconnect core can send phone number)
  Future<String> fetchUserId() async {
    Map result = await this._http.get(
          url:
              'https://s1.iranserver1.rayconnect.ir/api/v2/me?aid=${this.appId}',
          auth: true,
        );
    await storage.setItem('rayconnect-uid', result['uid']);
    return result['uid'];
  }

  // Logout and relogin as guest
  Future<bool> goodbye() async {
    try {
      await storage.removeItem('rayconnect-token');
      await storage.removeItem('rayconnect-uid');
      await this.asGuest();
      return true;
    } catch (e) {
      return false;
    }
  }
}
